Clazz.declarePackage("JU");
(function(){
var c$ = Clazz.declareType(JU, "GZIPOutputStream", null);
})();
;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
